/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.example;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import net.lucubrators.honeycomb.core.controller.HandleEvent;
import net.lucubrators.honeycomb.core.controller.Populate;
import net.lucubrators.honeycomb.core.messages.ErrorMessage;
import net.lucubrators.honeycomb.core.messages.Messages;
import net.lucubrators.honeycomb.core.shared.Model;
import net.lucubrators.honeycomb.core.shared.annotations.CombAttribute;
import net.lucubrators.honeycomb.core.shared.annotations.Param;
import net.lucubrators.honeycomb.core.view.View;
import net.lucubrators.honeycomb.defaultimpl.view.JSPView;

public class HelloNameController {

	public static final String	USERNAME_SESSION_KEY	= "username";

	@Populate
	public View populate(@CombAttribute("_view") String view, Model model, HttpServletRequest request) {
		HttpSession session = request.getSession();
		Object storedUsername = session.getAttribute(USERNAME_SESSION_KEY);
		model.put("username", storedUsername);
		return new JSPView(view);
	}

	@HandleEvent
	public View handleEvent(HttpServletRequest request, HttpServletResponse response, @Param(name = "username", fallBack = "") String username,
			@CombAttribute("_view") String view, Messages messages) throws IOException {
		if (username.isEmpty()) {
			messages.addMessage(new ErrorMessage("username", "username is empty"));
			request.getSession().removeAttribute(USERNAME_SESSION_KEY);
			return new JSPView(view);
		}
		request.getSession().setAttribute(USERNAME_SESSION_KEY, username);
		response.sendRedirect(request.getContextPath() + "/ex2.html");
		return null;
	}

}
